@@ -21,6 +21,7 @@
 #include <QMoveEvent>
 #include <QResizeEvent>
 #include <QScrollBar>
+#include <QGraphicsOpacityEffect>
 
 Flickable::Flickable(QWidget *parent) :
     QScrollArea(parent),
@@ -54,6 +55,41 @@ void Flickable::setY(int y) {
     }
 }
 
+qreal Flickable::opacity() const {
+    if (QGraphicsOpacityEffect *effect = qobject_cast<QGraphicsOpacityEffect*>(this->graphicsEffect())) {
+        return effect->opacity();
+    }
+
+    return 1.0;
+}
+
+void Flickable::setOpacity(qreal opacity) {
+    QGraphicsOpacityEffect *effect = qobject_cast<QGraphicsOpacityEffect*>(this->graphicsEffect());
+
+    if (!effect) {
+        effect = new QGraphicsOpacityEffect(this);
+        this->setGraphicsEffect(effect);
+    }
+
+    if (opacity != effect->opacity()) {
+        effect->setOpacity(opacity);
+        emit opacityChanged();
+    }
+}
+
+void Flickable::setFocus(bool focus) {
+    Q_D(const Flickable);
+
+    if ((d->complete) && (focus != this->hasFocus())) {
+        if (focus) {
+            this->setFocus(Qt::OtherFocusReason);
+        }
+        else {
+            this->clearFocus();
+        }
+    }
+}
+
 AnchorLine Flickable::left() const {
     Q_D(const Flickable);
 
@@ -185,7 +221,7 @@ void Flickable::changeEvent(QEvent *event) {
         break;
     }
 
-    QWidget::changeEvent(event);
+    QScrollArea::changeEvent(event);
 }
 
 void Flickable::moveEvent(QMoveEvent *event) {
@@ -197,7 +233,7 @@ void Flickable::moveEvent(QMoveEvent *event) {
         emit yChanged();
     }
 
-    QWidget::moveEvent(event);
+    QScrollArea::moveEvent(event);
 }
 
 void Flickable::resizeEvent(QResizeEvent *event) {
@@ -209,7 +245,27 @@ void Flickable::resizeEvent(QResizeEvent *event) {
         emit heightChanged();
     }
 
-    QWidget::resizeEvent(event);
+    QScrollArea::resizeEvent(event);
+}
+
+void Flickable::showEvent(QShowEvent *event) {
+    emit visibleChanged();
+    QScrollArea::showEvent(event);
+}
+
+void Flickable::hideEvent(QHideEvent *event) {
+    emit visibleChanged();
+    QScrollArea::hideEvent(event);
+}
+
+void Flickable::focusInEvent(QFocusEvent *event) {
+    emit focusChanged();
+    QScrollArea::focusInEvent(event);
+}
+
+void Flickable::focusOutEvent(QFocusEvent *event) {
+    emit focusChanged();
+    QScrollArea::focusOutEvent(event);
 }
 
 void Flickable::classBegin() {}
@@ -235,10 +291,28 @@ void FlickablePrivate::data_append(QDeclarativeListProperty<QObject> *list, QObj
 
     if (Flickable *flickable = qobject_cast<Flickable*>(list->object)) {
         flickable->d_func()->dataList.append(obj);
-        obj->setParent(flickable);
 
-        if ((!flickable->widget()) && (obj->isWidgetType())) {
-            flickable->setWidget(qobject_cast<QWidget*>(obj));
+        if (QWidget *widget = qobject_cast<QWidget*>(obj)) {
+            flickable->d_func()->childrenList.append(widget);
+
+            if (!flickable->widget()) {
+                flickable->setWidget(widget);
+            }
+        }
+    }
+}
+
+void FlickablePrivate::children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget) {
+    if (!widget) {
+        return;
+    }
+
+    if (Flickable *flickable = qobject_cast<Flickable*>(list->object)) {
+        flickable->d_func()->childrenList.append(widget);
+        flickable->d_func()->dataList.append(widget);
+
+        if (!flickable->widget()) {
+            flickable->setWidget(widget);
         }
     }
 }
@@ -250,6 +324,7 @@ void FlickablePrivate::actions_append(QDeclarativeListProperty<QObject> *list, Q
 
     if (Flickable *flickable = qobject_cast<Flickable*>(list->object)) {
         flickable->d_func()->actionList.append(obj);
+        flickable->d_func()->dataList.append(obj);
 
         if (!flickable->d_func()->complete) {
             return;
@@ -268,6 +343,10 @@ QDeclarativeListProperty<QObject> FlickablePrivate::data() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, FlickablePrivate::data_append);
 }
 
+QDeclarativeListProperty<QWidget> FlickablePrivate::children() {
+    return QDeclarativeListProperty<QWidget>(q_func(), 0, FlickablePrivate::children_append);
+}
+
 QDeclarativeListProperty<QObject> FlickablePrivate::actions() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, FlickablePrivate::actions_append);
 }
