@@ -44,6 +44,8 @@ public:
 
     static void data_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
 
+    static void children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget);
+
     static void actions_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
 
     Keys* attachedKeys();
@@ -52,6 +54,8 @@ public:
 
     virtual QDeclarativeListProperty<QObject> data();
 
+    virtual QDeclarativeListProperty<QWidget> children();
+
     virtual QDeclarativeListProperty<QObject> actions();
 
     bool qmlVisible() const;
@@ -78,6 +82,8 @@ public:
 
     QList<QObject*> dataList;
 
+    QList<QWidget*> childrenList;
+
     QList<QObject*> actionList;
 
     Q_DECLARE_PUBLIC(Item)
