@@ -19,6 +19,7 @@
 #define LISTVIEW_P_H
 
 #include "anchors_p.h"
+#include "modelindex_p.h"
 #include <QListView>
 #include <QDeclarativeParserStatus>
 #include <qdeclarative.h>
@@ -52,14 +53,16 @@ class ListView : public QListView, public QDeclarativeParserStatus
     Q_PROPERTY(bool atYEnd READ atYEnd NOTIFY contentYChanged)
     Q_PROPERTY(int contentX READ contentX WRITE setContentX NOTIFY contentXChanged)
     Q_PROPERTY(int contentY READ contentY WRITE setContentY NOTIFY contentYChanged)
+    Q_PROPERTY(qreal flickDeceleration READ flickDeceleration WRITE setFlickDeceleration NOTIFY flickDecelerationChanged)
+    Q_PROPERTY(qreal maximumFlickVelocity READ maximumFlickVelocity WRITE setMaximumFlickVelocity NOTIFY maximumFlickVelocityChanged)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeListProperty<QObject> data READ data)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
     Q_PRIVATE_PROPERTY(ListView::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
-    Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant model READ model WRITE setModel)
-    Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant rootIndex READ rootIndex WRITE setRootIndex)
-    Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant currentIndex READ currentIndex WRITE setCurrentIndex)
-    Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeComponent* delegate READ delegate WRITE setDelegate RESET resetDelegate)
+    Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant model READ model WRITE setModel NOTIFY modelChanged)
+    Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant rootIndex READ rootIndex WRITE setRootIndex NOTIFY rootIndexChanged)
+    Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant currentIndex READ currentIndex WRITE setCurrentIndex NOTIFY currentIndexChanged)
+    Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeComponent* delegate READ delegate WRITE setDelegate NOTIFY delegateChanged)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -128,10 +131,10 @@ signals:
     void contentYChanged();
     void flickDecelerationChanged();
     void maximumFlickVelocityChanged();
-
-protected slots:
-    void rowsInserted(const QModelIndex &parent, int start, int end);
-    void dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
+    void modelChanged();
+    void rootIndexChanged();
+    void currentIndexChanged();
+    void delegateChanged();
 
 protected:
     ListView(ListViewPrivate &dd, QWidget *parent = 0);
@@ -154,6 +157,5 @@ protected:
 };
 
 QML_DECLARE_TYPE(ListView)
-Q_DECLARE_METATYPE(QModelIndex)
 
 #endif // LISTVIEW_P_H
