@@ -17,6 +17,8 @@
 
 #include "webview_p.h"
 #include "webview_p_p.h"
+#include "webhistory_p.h"
+#include "websettings_p.h"
 #include <QMoveEvent>
 #include <QResizeEvent>
 #include <QActionGroup>
@@ -24,6 +26,7 @@
 #include <QScrollBar>
 #include <QAbstractKineticScroller>
 #include <QGraphicsOpacityEffect>
+#include <QDeclarativeEngine>
 
 WebView::WebView(QWidget *parent) :
     QWebView(parent),
@@ -33,6 +36,10 @@ WebView::WebView(QWidget *parent) :
 
     d->suppressor = new WebViewSelectionSuppressor(this);
 
+    if (QDeclarativeEngine *engine = qmlEngine(this)) {
+        this->page()->setNetworkAccessManager(engine->networkAccessManager());
+    }
+
     this->setTextSelectionEnabled(false);
     this->connect(this, SIGNAL(titleChanged(QString)), this, SIGNAL(titleChanged()));
     this->connect(this, SIGNAL(urlChanged(QUrl)), this, SIGNAL(urlChanged()));
@@ -45,6 +52,10 @@ WebView::WebView(WebViewPrivate &dd, QWidget *parent) :
     QWebView(parent),
     d_ptr(&dd)
 {
+    if (QDeclarativeEngine *engine = qmlEngine(this)) {
+        this->page()->setNetworkAccessManager(engine->networkAccessManager());
+    }
+
     this->setTextSelectionEnabled(false);
     this->connect(this, SIGNAL(titleChanged(QString)), this, SIGNAL(titleChanged()));
     this->connect(this, SIGNAL(urlChanged(QUrl)), this, SIGNAL(urlChanged()));
@@ -410,6 +421,26 @@ QDeclarativeListProperty<QObject> WebViewPrivate::actions() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, WebViewPrivate::actions_append);
 }
 
+WebHistory* WebViewPrivate::history() {
+    Q_Q(WebView);
+
+    if (!webHistory) {
+        webHistory = new WebHistory(q->history(), q);
+    }
+
+    return webHistory;
+}
+
+WebSettings* WebViewPrivate::settings() {
+    Q_Q(WebView);
+
+    if (!webSettings) {
+        webSettings = new WebSettings(q->settings(), q);
+    }
+
+    return webSettings;
+}
+
 void WebViewPrivate::_q_onLoadStarted() {
     Q_Q(WebView);
 
