@@ -23,6 +23,8 @@
 #include <QDeclarativeParserStatus>
 #include <qdeclarative.h>
 
+class WebHistory;
+class WebSettings;
 class WebViewPrivate;
 
 class WebView : public QWebView, public QDeclarativeParserStatus
@@ -56,6 +58,8 @@ class WebView : public QWebView, public QDeclarativeParserStatus
     Q_PROPERTY(int contentY READ contentY WRITE setContentY NOTIFY contentYChanged)
     Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
     Q_PROPERTY(Status status READ status NOTIFY statusChanged)
+    Q_PRIVATE_PROPERTY(WebView::d_func(), WebHistory* history READ history CONSTANT FINAL)
+    Q_PRIVATE_PROPERTY(WebView::d_func(), WebSettings* settings READ settings CONSTANT FINAL)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> data READ data)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
@@ -142,7 +146,7 @@ signals:
     void progressChanged();
     void statusChanged();
 
-private:
+protected:
     WebView(WebViewPrivate &dd, QWidget *parent = 0);
 
     void changeEvent(QEvent *event);
@@ -159,6 +163,7 @@ private:
     QScopedPointer<WebViewPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(WebView)
+    Q_DISABLE_COPY(WebView)
 
     Q_PRIVATE_SLOT(d_func(), void _q_onLoadStarted())
     Q_PRIVATE_SLOT(d_func(), void _q_onLoadFinished(bool))
