@@ -106,6 +106,8 @@ public:
         ItemPrivate(parent),
         suppressor(0),
         kineticScroller(parent->property("kineticScroller").value<QAbstractKineticScroller*>()),
+        webHistory(0),
+        webSettings(0),
         progress(0),
         status(WebView::Null)
     {
@@ -123,6 +125,10 @@ public:
 
     QDeclarativeListProperty<QObject> actions();
 
+    WebHistory* history();
+
+    WebSettings* settings();
+
     void _q_onLoadStarted();
     void _q_onLoadFinished(bool ok);
     void _q_onLoadProgress(int p);
@@ -131,6 +137,10 @@ public:
 
     QAbstractKineticScroller *kineticScroller;
 
+    WebHistory *webHistory;
+
+    WebSettings *webSettings;
+
     int progress;
 
     WebView::Status status;
